mailr3902 - /1.3/test_suite/unit_tests/_prompt/test_diffusion_tensor.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on November 25, 2007 - 15:14:
Author: bugman
Date: Sun Nov 25 15:14:00 2007
New Revision: 3902

URL: http://svn.gna.org/viewcvs/relax?rev=3902&view=rev
Log:
Created the framework for the unit tests of the diffusion_tensor user 
functions.


Added:
    1.3/test_suite/unit_tests/_prompt/test_diffusion_tensor.py
      - copied, changed from r3899, 
1.3/test_suite/unit_tests/_prompt/test_molecule.py

Copied: 1.3/test_suite/unit_tests/_prompt/test_diffusion_tensor.py (from 
r3899, 1.3/test_suite/unit_tests/_prompt/test_molecule.py)
URL: 
http://svn.gna.org/viewcvs/relax/1.3/test_suite/unit_tests/_prompt/test_diffusion_tensor.py?p2=1.3/test_suite/unit_tests/_prompt/test_diffusion_tensor.py&p1=1.3/test_suite/unit_tests/_prompt/test_molecule.py&r1=3899&r2=3902&rev=3902&view=diff
==============================================================================
--- 1.3/test_suite/unit_tests/_prompt/test_molecule.py (original)
+++ 1.3/test_suite/unit_tests/_prompt/test_diffusion_tensor.py Sun Nov 25 
15:14:00 2007
@@ -28,9 +28,9 @@
 from data import Data as relax_data_store
 from data_types import DATA_TYPES
 from generic_fns import residue
-from prompt.molecule import Molecule
+from prompt.diffusion_tensor import Diffusion_tensor
 from relax_errors import RelaxError, RelaxIntError, RelaxNoPipeError, 
RelaxNoneStrError, RelaxStrError
-from test_suite.unit_tests.molecule_testing_base import Molecule_base_class
+from test_suite.unit_tests.diffusion_tensor_testing_base import 
Diffusion_tensor_base_class
 
 # Set the variable sys.ps3 (this is required by the user functions).
 sys.ps3 = 'relax> '
@@ -46,129 +46,9 @@
 relax.interpreter.intro = True
 
 
-class Test_molecule(Molecule_base_class, TestCase):
-    """Unit tests for the functions of the 'prompt.molecule' module."""
+class Test_diffusion_tensor(Diffusion_tensor_base_class, TestCase):
+    """Unit tests for the functions of the 'prompt.diffusion_tensor' 
module."""
 
     # Instantiate the user function class.
-    molecule_fns = Molecule(relax)
+    diffusion_tensor_fns = Diffusion_tensor(relax)
     residue_fns = residue
-
-
-    def test_copy_argfail_pipe_from(self):
-        """Test the proper failure of the molecule.copy() user function for 
the pipe_from argument."""
-
-        # Loop over the data types.
-        for data in DATA_TYPES:
-            # Catch the None and str arguments, and skip them.
-            if data[0] == 'None' or data[0] == 'str':
-                continue
-
-            # The argument test.
-            self.assertRaises(RelaxNoneStrError, self.molecule_fns.copy, 
pipe_from=data[1], mol_from='#Old mol', mol_to='#Old mol')
-
-
-    def test_copy_argfail_mol_from(self):
-        """Test the proper failure of the molecule.copy() user function for 
the mol_from argument."""
-
-        # Loop over the data types.
-        for data in DATA_TYPES:
-            # Catch the str argument, and skip it.
-            if data[0] == 'str':
-                continue
-
-            # The argument test.
-            self.assertRaises(RelaxStrError, self.molecule_fns.copy, 
mol_from=data[1], mol_to='#Old mol')
-
-
-    def test_copy_argfail_pipe_to(self):
-        """Test the proper failure of the molecule.copy() user function for 
the pipe_to argument."""
-
-        # Loop over the data types.
-        for data in DATA_TYPES:
-            # Catch the None and str arguments, and skip them.
-            if data[0] == 'None' or data[0] == 'str':
-                continue
-
-            # The argument test.
-            self.assertRaises(RelaxNoneStrError, self.molecule_fns.copy, 
pipe_to=data[1], mol_from='#Old mol', mol_to='#New mol2')
-
-
-    def test_copy_argfail_mol_to(self):
-        """Test the proper failure of the molecule.copy() user function for 
the mol_to argument."""
-
-        # Set up some data.
-        self.setup_data()
-
-        # Loop over the data types.
-        for data in DATA_TYPES:
-            # Catch the None and str arguments, and skip them.
-            if data[0] == 'None' or data[0] == 'str':
-                continue
-
-            # The argument test.
-            self.assertRaises(RelaxNoneStrError, self.molecule_fns.copy, 
mol_from='#Old mol', mol_to=data[1])
-
-
-    def test_create_argfail_mol_name(self):
-        """Test the proper failure of the molecule.create() user function 
for the mol_name argument."""
-
-        # Loop over the data types.
-        for data in DATA_TYPES:
-            # Catch the str arguments, and skip them.
-            if data[0] == 'str':
-                continue
-
-            # The argument test.
-            self.assertRaises(RelaxStrError, self.molecule_fns.create, 
mol_name=data[1])
-
-
-    def test_delete_argfail_mol_id(self):
-        """Test the proper failure of the molecule.delete() user function 
for the mol_id argument."""
-
-        # Loop over the data types.
-        for data in DATA_TYPES:
-            # Catch the str arguments, and skip them.
-            if data[0] == 'str':
-                continue
-
-            # The argument test.
-            self.assertRaises(RelaxStrError, self.molecule_fns.delete, 
mol_id=data[1])
-
-
-    def test_display_argfail_mol_id(self):
-        """Test the proper failure of the molecule.display() user function 
for the mol_id argument."""
-
-        # Loop over the data types.
-        for data in DATA_TYPES:
-            # Catch the None and str arguments, and skip them.
-            if data[0] == 'None' or data[0] == 'str':
-                continue
-
-            # The argument test.
-            self.assertRaises(RelaxNoneStrError, self.molecule_fns.display, 
mol_id=data[1])
-
-
-    def test_rename_argfail_mol_id(self):
-        """Test the proper failure of the molecule.rename() user function 
for the mol_id argument."""
-
-        # Loop over the data types.
-        for data in DATA_TYPES:
-            # Catch the str arguments, and skip them.
-            if data[0] == 'str':
-                continue
-
-            # The argument test.
-            self.assertRaises(RelaxStrError, self.molecule_fns.rename, 
mol_id=data[1])
-
-
-    def test_rename_argfail_new_name(self):
-        """Test the proper failure of the molecule.rename() user function 
for the new_name argument."""
-
-        # Loop over the data types.
-        for data in DATA_TYPES:
-            # Catch the str arguments, and skip them.
-            if data[0] == 'str':
-                continue
-
-            # The argument test.
-            self.assertRaises(RelaxStrError, self.molecule_fns.rename, 
new_name=data[1])




Related Messages


Powered by MHonArc, Updated Sun Nov 25 15:20:41 2007